# hpo-toolkit
A toolkit for working with Human Phenotype Ontology in Python

`hpo-toolkit` is still in *alpha* stage, the APIs may change.

## Install

HPO toolkit is available from PyPi:

```shell
pip install hpo-toolkit
```

## Run tests

We use `tox` to run tests.
 
```shell
pip install -U tox
tox run
```

## Examples

Check out the [notebooks](https://github.com/TheJacksonLaboratory/hpo-toolkit/tree/main/notebooks) folder for Jupyter 
notebooks with an example usage.
